;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "guava-themes" "0.15.0"
  "A pack of plant-inspired themes."
  '((emacs "24.1"))
  :url "https://github.com/bormoge/guava-themes"
  :commit "50881883b9ca7fbceb9bfedb04d2a16ea01125bb"
  :revdesc "v0.15.0-0-g50881883b9ca"
  :keywords '("themes" "faces" "color")
  :authors '(("Geralld Borbón" . "eternalmangocean@gmail.com"))
  :maintainers '(("Geralld Borbón" . "eternalmangocean@gmail.com")))
